MdiController class
Methods
-
addListener(VoidCallback listener)
→ void
-
Register a closure to be called when the object changes.
inherited
-
addWindow({required String title, required Widget body, Alignment? parentWidgetAlignment, double? minWidth, double? minHeight, double? width, double? height, double? placementPadding, double? x, double? y, Color? bodyColor})
→ dynamic
-
-
closeWindow(Key key)
→ dynamic
-
-
dispose()
→ void
-
Discards any resources used by the object.
inherited
-
dragWindow({required Key key, required double dx, required double dy})
→ dynamic
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners()
→ void
-
Call all the registered listeners.
inherited
-
onFocus(Key key)
→ dynamic
-
-
removeListener(VoidCallback listener)
→ void
-
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
resizeWindow({required Key key, required double dx, required double dy, bool moveHorizontalBase = false, bool moveVerticalBase = false})
→ dynamic
-
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
addWindowTo(BuildContext context, {required String title, required Widget body, Alignment? parentWidgetAlignment, double? minWidth, double? minHeight, double? width, double? height, double? placementPadding, double? x, double? y, Color? bodyColor})
→ void
-
-
closeWindowIn(BuildContext context)
→ void
-